=====================
Unsupervised learning
=====================

Outlier detection
=================
Wildboar includes one estimator for outlier detection: the ``IsolationShapeletForest``.


.. toctree::
   :maxdepth: 2
   :hidden:

   unsupervised/pattern_discovery
   unsupervised/outlier_detection